@@ -8,7 +8,7 @@ use LWP::UserAgent;
 use JSON;
 use List::Util qw(first);
 
-our $VERSION = 0.5;
+our $VERSION = '0.6';
 
 sub new {
     my ($class, %params) = @_;
@@ -64,7 +64,7 @@ sub get_policy_id {
 sub import_policy {
     my ($self, %params) = @_;
 
-    croak "missing file name parameter" unless $params{id};
+    croak "missing file name parameter" unless $params{file};
 
     my $result = $self->_post("/policies/import", %params);
     return $result;
@@ -170,7 +170,7 @@ sub list_scans {
     my ($self, %params) = @_;
 
     my $result = $self->_get('/scans', %params);
-    return $result ? @{$result} : ();
+    return $result->{scans} ? @{$result->{scans}} : ();
 }
 
 sub launch_scan {
@@ -194,6 +194,16 @@ sub get_scan_details {
     return $result;
 }
 
+sub stop_scan {
+    my ($self, %params) = @_;
+
+    croak "missing scan_id parameter" unless $params{scan_id};
+
+    my $scan_id = delete $params{scan_id};
+    my $result  = $self->_post("/scans/$scan_id/stop", %params);
+    return $result;
+}
+
 sub set_scan_read_status {
     my ($self, %params) = @_;
 
@@ -219,9 +229,11 @@ sub export_scan {
                                             $params{format} eq 'csv'    or
                                             $params{format} eq 'db';
 
-    my $scan_id = delete $params{scan_id};
+    my $scan_id    = delete $params{scan_id};
+    my $history_id = delete $params{history_id};
 
-    my $result = $self->_post("/scans/$scan_id/export", %params);
+    my $history_param = defined $history_id ? "?history_id=$history_id" : "";
+    my $result = $self->_post("/scans/$scan_id/export$history_param", %params);
     return $result->{file};
 }
 
@@ -353,7 +365,7 @@ sub list_scanners {
     my ($self) = @_;
 
     my $result = $self->_get("/scanners");
-    return $result->{scanner} ? @{$result->{scanner}} : ();
+    return $result->{scanners} ? @{$result->{scanners}} : ();
 }
 
 sub list_folders {
@@ -587,7 +599,10 @@ using REST interface.
         format  => 'pdf'
     );
 
-    while ($nessus->get_scan_export_status(scan_id => $scan_id, file_id => $file_id) ne 'ready') {
+    while ($nessus->get_scan_export_status(
+        scan_id => $scan->{id},
+        file_id => $file_id
+    ) ne 'ready') {
         sleep 1;
     }
 
@@ -633,7 +648,7 @@ Returns a reference to a hash with all settings and parameters for a given scan
 
 See L<https://your.nessus.server:8834/api#/resources/policies/details> for details.
 
-=head2 $nessus->import_policy(id => $file_id)
+=head2 $nessus->import_policy(file => $file_id)
 
 Returns reference to hash with name and identifier of the policy imported.
 NB $file_id must be a valid identifier to a file uploaded to the Nessus server,
@@ -643,7 +658,7 @@ Example:
 $result = $nessus->import_policy(file => $fileuploaded);
 print "Policy imported: " . $result->{'name'} . "\n";
 
-See L<https://your.nessus.server:8834/api#/resources/file/upload> for details.
+See L<https://your.nessus.server:8834/api#/resources/policies/import> for details.
 
 =head2 $nessus->delete_policy(id => $policy_id)
 
@@ -651,6 +666,14 @@ Deletes a given scan policy off the Nessus server
 
 See L<https://your.nessus.server:8834/api#/resources/policies/delete> for details.
 
+=head2 $nessus->configure_policy(id => $policy_id, uuid => $uuid, settings => $settings)
+
+See L<https://your.nessus.server:8834/api#/resources/policies/configure> for details.
+
+=head2 $nessus->create_policy(uuid => $uuid, settings => $settings)
+
+See L<https://your.nessus.server:8834/api#/resources/policies/create> for details.
+
 =head2 $nessus->list_scanners()
 
 Returns the scanner list.
@@ -801,6 +824,12 @@ my $fileuploaded = $result->{'fileuploaded'};
 
 See L<https://your.nessus.server:8834/api#/resources/file/upload> for details.
 
+=head2 $nessus->stop_scan(scan_id => $scan_id )
+
+Returns details for the given scan.
+
+See L<https://your.nessus.server:8834/nessus6-api.html#/resources/scans/stop> for details.
+
 =head1 LICENSE
 
 This program is free software: you can redistribute it and/or modify
